fake.py examples
================

- `Customization <customization/README.rst>`_.
- `Dataclasses <dataclasses/README.rst>`_.
- `Django <django/README.rst>`_.
- `Hypothesis <hypothesis/README.rst>`_.
- `Lazy/Fuzzy <lazyfuzzy/README.rst>`_.
- `Pydantic <pydantic/README.rst>`_.
- `SQLAlchemy <sqlalchemy/README.rst>`_.
- `TortoiseORM <tortoise/README.rst>`_.
